@@ -556,6 +556,29 @@ class EmrClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeServiceNodeInfos(self, request):
+        """查询服务进程信息
+
+        :param request: Request instance for DescribeServiceNodeInfos.
+        :type request: :class:`tencentcloud.emr.v20190103.models.DescribeServiceNodeInfosRequest`
+        :rtype: :class:`tencentcloud.emr.v20190103.models.DescribeServiceNodeInfosResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeServiceNodeInfos", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeServiceNodeInfosResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeTrinoQueryInfo(self, request):
         """获取trino查询结果
 
@@ -626,6 +649,29 @@ class EmrClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeYarnScheduleHistory(self, request):
+        """查看yarn资源调度的调度历史
+
+        :param request: Request instance for DescribeYarnScheduleHistory.
+        :type request: :class:`tencentcloud.emr.v20190103.models.DescribeYarnScheduleHistoryRequest`
+        :rtype: :class:`tencentcloud.emr.v20190103.models.DescribeYarnScheduleHistoryResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeYarnScheduleHistory", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeYarnScheduleHistoryResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def InquirePriceRenewEmr(self, request):
         """集群续费询价。
 
@@ -741,6 +787,30 @@ class EmrClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ModifyAutoRenewFlag(self, request):
+        """前提：预付费集群
+        资源级别开启或关闭自动续费
+
+        :param request: Request instance for ModifyAutoRenewFlag.
+        :type request: :class:`tencentcloud.emr.v20190103.models.ModifyAutoRenewFlagRequest`
+        :rtype: :class:`tencentcloud.emr.v20190103.models.ModifyAutoRenewFlagResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyAutoRenewFlag", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyAutoRenewFlagResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ModifyAutoScaleStrategy(self, request):
         """修改自动扩缩容规则
 
@@ -879,6 +949,29 @@ class EmrClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ModifyYarnDeploy(self, request):
+        """部署生效
+
+        :param request: Request instance for ModifyYarnDeploy.
+        :type request: :class:`tencentcloud.emr.v20190103.models.ModifyYarnDeployRequest`
+        :rtype: :class:`tencentcloud.emr.v20190103.models.ModifyYarnDeployResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyYarnDeploy", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyYarnDeployResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def RunJobFlow(self, request):
         """创建流程作业
 
